@@ -4,16 +4,18 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
+                       $RE_WILDCARD_BASH
                        contains_wildcard
+                       convert_wildcard_to_sql
                );
 
 # note: order is important here, brace encloses the other
-my $re1 =
+our $RE_WILDCARD_BASH =
     qr(
           # non-escaped brace expression, with at least one comma
           (?P<brace>
@@ -44,18 +46,43 @@ my $re1 =
               # non-escaped * and ?
               (?<!\\)(?:\\\\)*[*?]
           )
+      |
+          (?P<sql_wc>
+              # non-escaped % and ?
+              (?<!\\)(?:\\\\)*[%_]
+          )
       )ox;
 
 sub contains_wildcard {
     my $str = shift;
 
-    while ($str =~ /$re1/go) {
+    while ($str =~ /$RE_WILDCARD_BASH/go) {
         my %m = %+;
         return 1 if $m{brace} || $m{class} || $m{joker};
     }
     0;
 }
 
+sub convert_wildcard_to_sql {
+    my $str = shift;
+
+    $str =~ s/$RE_WILDCARD_BASH/
+        if ($+{joker}) {
+            if ($+{joker} eq '*') {
+                "%";
+            } else {
+                "_";
+            }
+        } elsif ($+{sql_wc}) {
+            "\\$+{sql_wc}";
+        } else {
+            $&;
+        }
+    /eg;
+
+    $str;
+}
+
 1;
 # ABSTRACT: Bash wildcard string routines
 
@@ -71,16 +98,22 @@ String::Wildcard::Bash - Bash wildcard string routines
 
 =head1 VERSION
 
-This document describes version 0.02 of String::Wildcard::Bash (from Perl distribution String-Wildcard-Bash), released on 2015-01-03.
+This document describes version 0.03 of String::Wildcard::Bash (from Perl distribution String-Wildcard-Bash), released on 2015-09-10.
 
 =head1 SYNOPSIS
 
-    use String::Wildcard::Bash qw(contains_wildcard);
+    use String::Wildcard::Bash qw(
+        $RE_WILDCARD_BASH
+        contains_wildcard
+        convert_wildcard_to_sql
+    );
 
     say 1 if contains_wildcard(""));      # -> 0
     say 1 if contains_wildcard("ab*"));   # -> 1
     say 1 if contains_wildcard("ab\\*")); # -> 0
 
+    say convert_wildcard_to_sql("foo*");  # -> "foo%"
+
 =head1 DESCRIPTION
 
 =for Pod::Coverage ^(qqquote)$
@@ -103,6 +136,24 @@ C<$HOME>), arithmetic expression (e.g. C<$[1+2]>), history (C<!>), and so on.
 Although this module has 'Bash' in its name, this set of wildcards should be
 applicable to other Unix shells. Haven't checked completely though.
 
+=head2 convert_wildcard_to_sql($str) => str
+
+Convert bash wildcard to SQL. This includes:
+
+=over
+
+=item * converting unescaped C<*> to C<%>
+
+=item * converting unescaped C<?> to C<_>
+
+=item * escaping unescaped <%>
+
+=item * escaping unescaped C<_>
+
+=back
+
+Unsupported constructs currently will be passed as-is.
+
 =head1 SEE ALSO
 
 L<Regexp::Wildcards> to convert a string with wildcard pattern to equivalent
